@@ -1,4 +1,3 @@
-# coding: utf-8
 from __future__ import unicode_literals
 
 import copy
@@ -16,10 +15,13 @@ class TapiInstantiator(object):
     def __init__(self, adapter_class):
         self.adapter_class = adapter_class
 
-    def __call__(self, serializer_class=None, session=None, **kwargs):
+    def __call__(self, serializer_class=None, session=None, resource_mapping=None, **kwargs):
         refresh_token_default = kwargs.pop("refresh_token_by_default", False)
         return TapiClient(
-            self.adapter_class(serializer_class=serializer_class),
+            self.adapter_class(
+                serializer_class=serializer_class,
+                resource_mapping=resource_mapping,
+            ),
             api_params=kwargs,
             refresh_token_by_default=refresh_token_default,
             session=session,
@@ -183,7 +185,7 @@ class TapiClient(object):
     def __getattr__(self, name):
         ret = self._get_client_from_name_or_fallback(name)
         if ret is None:
-            raise AttributeError(name)
+            raise AttributeError(f"Undeclared resource '{name}'")
         return ret
 
     def __getitem__(self, key):
